<?php
	
	
	/*
		
		
		Plugin Name: GDY Cookie Note
		Tags: gdy, cookie, note
		Plugin URI: https://wordpress.org/plugins/gdy-cookie-note/
		Author: Johannes Grandy
		Author URI: http://johannesgrandy.com/
		Text Domain: gdy-cookie-note
		Domain Path: /languages
		Description: The most lightweight yet customizable cookie plugin with hook based settings.
		License: GPLv2 or later
		License URI: http://www.gnu.org/licenses/gpl-2.0.html
		Copyright: Johannes Grandy
		Version: 0.1.0
		Build: 1

	
	*/
	



	/*********************************** TRANSLATION *********************************/
	
	load_plugin_textdomain( 'gdy-cookie-note', false, plugin_basename( __DIR__ ) . '/languages/' );
	





	/*************************** SET SURPRESS MESSAGE ***************************/

	add_action( 'init', 'gdycn_init' );

	function gdycn_init() {
	  
		if( isset( $_GET[ 'gdycn_close' ] ) ):

			$expiration = apply_filters( 'gdycn_expiration', strtotime( '+90 days' ) );

			setcookie( 'gdycn_suppress_note', '1', $expiration, COOKIEPATH, COOKIE_DOMAIN );

		endif;

	}




	/*************************** CHECK IF THE COOKIE NOTE SHOULD BE SHOWN ***************************/

	function gdycn_show_note() {
		
		if( isset( $_COOKIE[ 'gdycn_suppress_note' ] ) ):

			$return = false;

		else:

			$return = true;

		endif;

		return apply_filters( 'gdycn_show_note', $return );
		
	}




	/*************************** REGISTER STYLES & SCRIPTS ***************************/
	
	add_action( 'wp_enqueue_scripts', function() {
		

		// Admin styles and scripts

		if( !is_admin() AND gdycn_show_note() ): 
			

			// Styles

			wp_enqueue_style( 'gdy-cookie-note', plugins_url( '/style.css', __FILE__ ) );


			// Scripts

			wp_enqueue_script( 'jquery' );

			wp_enqueue_script( 'gdy-cookie-note', plugins_url( '/script.js', __FILE__ ), array( 'jquery' ) );


			// Javascript data

			wp_localize_script( 'gdy-cookie-note', 'gdycn', array(

				'body_class' => apply_filters( 'gdycn_body_class', 'cookie_note' ),
				'cookie_expiration' => apply_filters( 'gdycn_expiration', date( 'D, j M Y H:i:s \U\T\C', strtotime( '+90 days' ) ) ),

			) );
			

		endif;


	} );

	



	/************************************** BODY CLASS ********************************/
	
	add_filter( 'body_class', 'gdycn_body_class' );

	function gdycn_body_class( $classes = '' ) {

		$class = apply_filters( 'gdycn_body_class', 'cookie_note' );

		if( gdycn_show_note() ) $classes[] = $class; 
		
		return $classes;
		
	}




	/*************************** THE NOTE ACTION ***************************/

	add_action( 'wp_footer', 'gdycn_note' );

	function gdycn_note() {
		
		if( gdycn_show_note() ):

			do_action( 'gdycn_note' );

		endif;
	
	}




	/*************************** THE ACTUAL NOTE ***************************/

	add_action( 'gdycn_note', 'gdycn_default_note' );

	function gdycn_default_note() {
		
		$text = apply_filters( 'gdycn_note_text', __( 'Cookies: This website uses cookies to function properly and to provide you with an optimal user experience. If you agree, continue your visit on our website.', 'gdy-cookie-note' ) );

		echo '<div id="gdycn_container">';

			echo '<div id="gdycn_overlay"></div>';

			echo '<div id="gdycn_note">';

				echo '<div id="gdycn_inner">';

					echo '<a href="' . add_query_arg( 'gdycn_close', '', get_permalink() ) . '" id="gdycn_close">';

						echo '<span id="gdycn_close_inner">&#10005;</span>';

					echo '</a>';

					echo '<div id="gdycn_text">' . $text . '</div>';

				echo '</div>';

			echo '</div>';

		echo '</div>';
	
	}



	



	
	
	
?>